@@ -13,7 +13,7 @@
  *      Anatoly Vorobey <mellon@pobox.com>
  *      Brad Fitzpatrick <brad@danga.com>
  *
- *  $Id: memcached.c,v 1.26 2003/06/27 21:15:55 bradfitz Exp $
+ *  $Id: memcached.c,v 1.28 2003/07/22 09:14:33 bradfitz Exp $
  */
 
 #include "config.h"
@@ -46,6 +46,17 @@ static item **todelete = 0;
 static int delcurr;
 static int deltotal;
 
+time_t realtime(time_t exptime) {
+    time_t now = time(0);
+
+    /* no. of seconds in 30 days - largest possible delta exptime */
+    #define REALTIME_MAXDELTA 60*60*24*30
+
+    if (exptime > REALTIME_MAXDELTA)
+        return exptime;
+    else return exptime + now;
+}
+
 void stats_init(void) {
     stats.curr_items = stats.total_items = stats.curr_conns = stats.total_conns = stats.conn_structs = 0;
     stats.get_cmds = stats.set_cmds = stats.get_hits = stats.get_misses = 0;
@@ -264,11 +275,16 @@ void process_stat(conn *c, char *command) {
         char temp[1024];
         pid_t pid = getpid();
         char *pos = temp;
+        struct rusage usage;
+        
+        getrusage(RUSAGE_SELF, &usage);
 
         pos += sprintf(pos, "STAT pid %u\r\n", pid);
         pos += sprintf(pos, "STAT uptime %lu\r\n", now - stats.started);
         pos += sprintf(pos, "STAT time %u\r\n", now);
         pos += sprintf(pos, "STAT version " VERSION "\r\n");
+        pos += sprintf(pos, "STAT rusage_user %u:%u\r\n", usage.ru_utime.tv_sec, usage.ru_utime.tv_usec);
+        pos += sprintf(pos, "STAT rusage_system %u:%u\r\n", usage.ru_stime.tv_sec, usage.ru_stime.tv_usec);
         pos += sprintf(pos, "STAT curr_items %u\r\n", stats.curr_items);
         pos += sprintf(pos, "STAT total_items %u\r\n", stats.total_items);
         pos += sprintf(pos, "STAT bytes %llu\r\n", stats.curr_bytes);
@@ -442,6 +458,7 @@ void process_command(conn *c, char *command) {
             out_string(c, "CLIENT_ERROR bad command line format");
             return;
         }
+        expire = realtime(expire);
         it = item_alloc(key, flags, expire, len+2);
         if (it == 0) {
             out_string(c, "SERVER_ERROR out of memory");
@@ -570,19 +587,22 @@ void process_command(conn *c, char *command) {
 
     if (strncmp(command, "delete ", 7) == 0) {
         char key[251];
-        char *start = command+7;
         item *it;
+        int res;
+        time_t exptime = 0;
 
-        sscanf(start, " %250s", key);
+        res = sscanf(command, "%*s %250s %d", key, &exptime);
         it = assoc_find(key);
         if (!it) {
             out_string(c, "NOT_FOUND");
             return;
         }
 
+        exptime = realtime(exptime);
+
         it->refcount++;
         /* use its expiration time as its deletion time now */
-        it->exptime = time(0) + 4;
+        it->exptime = exptime;
         it->it_flags |= ITEM_DELETED;
         todelete[delcurr++] = it;
         if (delcurr >= deltotal) {
