@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*- */
-/* $Id: memcached.h,v 1.15 2003/06/27 21:15:55 bradfitz Exp $ */
+/* $Id: memcached.h,v 1.16 2003/07/22 09:14:33 bradfitz Exp $ */
 
 #define DATA_BUFFER_SIZE 2048
 
@@ -130,6 +130,14 @@ extern int l_socket;
  * Functions
  */
 
+/* 
+ * given time value that's either unix time or delta from current unix time, return
+ * unix time. Use the fact that delta can't exceed one month (and real time value can't 
+ * be that low).
+ */
+
+time_t realtime(time_t exptime);
+
 /* slabs memory allocation */
 
 /* Init the subsystem. The argument is the limit on no. of bytes to allocate, 0 if no limit */
